
#include <SPI.h>
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include "images.h"

/********************************************************************************/
// Screen
#define SCREEN_WIDTH 128 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels

// Declaration for an SSD1306 display connected to I2C (SDA, SCL pins)
#define OLED_RESET     -1 // Reset pin # (or -1 if sharing Arduino reset pin)
Adafruit_SSD1306 display(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, OLED_RESET);

#define LOGO_HEIGHT       16
#define LOGO_WIDTH        16
#define SCREEN_ROTATION   0
/********************************************************************************/

void setup() {

  Serial.begin(115200);

  // SSD1306_SWITCHCAPVCC = generate display voltage from 3.3V internally
  if (!display.begin(SSD1306_SWITCHCAPVCC, 0x3C)) { // Address 0x3D for 128x64
    Serial.println(F("SSD1306 allocation failed"));
    for (;;); // Don't proceed, loop forever
  }
  drawImage(dt_logo_imageDT_Icon_128x64, SCREEN_ROTATION);

  delay(2000); // Pause for 2 seconds
  display.clearDisplay();

  delay(500);

  drawImage(image_Scan_Card_2_01, SCREEN_ROTATION);
  delay(2000);

}

void loop() {
  // invert the pixels. Black to white etc
  display.invertDisplay(true);
  delay(1000);
  display.invertDisplay(false);
  delay(1000);

}


/********** Screen Functions ************/
// Write text on the screen starting from top left working right and down lines
void DrawString(String str) {
  display.clearDisplay();

  display.setTextSize(2);             // Normal 1:1 pixel scale
  display.setTextColor(SSD1306_WHITE);        // Draw white text
  display.setCursor(0, 0);            // Start at top-left corner
  //  display.println(F("GSheet C2:"));
  //  display.setCursor(0,1);             // Start at top-left corner
  display.println(F(str.c_str()));
  display.display();
  delay(2000);
}

// Specifically two lines of text 
void DrawSeperateLines(String _line1, String _line2) {
  display.clearDisplay();
  display.setTextSize(2);             // Normal 1:1 pixel scale
  display.setTextColor(SSD1306_WHITE);        // Draw white text
  display.setCursor(0, 0);            // Start at top-left corner
  display.println(F(_line1.c_str()));
  display.setCursor(0, 22);            // Start one line down, left side
  display.println(F(_line2.c_str()));
  display.display();
  delay(2000);
}

//Draw a byte array and specify the rotation
void drawImage(uint8_t * imageName, uint8_t rotation)
{
  display.setRotation(rotation);
  display.clearDisplay();
  //display.drawBitmap(0, 0, image_data_Image, 128, 64, 1);
  display.drawBitmap(0, 0, imageName, 128, 64, 1);
  display.display();
}
